@@ -6,6 +6,6 @@ y = np.random.randn(100)
 fig, ax = plt.subplots()
 fig.patch.set_facecolor('#2D2E35')
 ax.patch.set_facecolor('#2D2E35')
-ax.scatter(x, y)
+ax.scatter(x, y)    # TRY putting ax.step(x, y) in here instead.
 ax.text(x=0, y=0, s="<py>", c="orange")
-fig
+display(fig, target="app")
